@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1600';
+our $VERSION = '0.1601';
 
 use strict;
 use warnings;
@@ -398,7 +398,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1600
+version 0.1601
 
 =head1 SYNOPSIS
 
@@ -406,17 +406,17 @@ version 0.1600
   # * Call each function below with Mock::Populate::foo(...
   my $n      = 5;
   my $offset = 11;
-  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0, N => $n);
-  my $money  = number_ranger(start => 1000, end => 5000, prec => 2, random => 1, N => $n);
+  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0);
+  my $money  = number_ranger(start => 1000, end => 5000, prec => 2, N => $n);
   my $create = date_ranger(start => '1900-01-01', end => '2020-12-31', N => $n);
   my $modify = date_modifier($offset, @$create);
   my $times  = time_ranger(stamp => 1, start => '01:02:03', end =>'23:59:59', N => $n);
-  my $people = name_ranger(gender => 'b', names => 2, country => 'us', N => $n);
+  my $people = name_ranger(gender => 'f', N => $n);
   my $email  = email_ranger(@$people);
   my $shuff  = shuffler(qw(foo bar baz goo ber buz));
   my $stats  = distributor(type => 'u', prec => 4, dof => 2, N => $n);
   my $string = string_ranger(length => 32, type => 'base64', N => $n);
-  my $imgs   = image_ranger(size => 10, N => $n);  # *size is density, not pixel dimension
+  my $imgs   = image_ranger(size => 10, N => $n);  # size is density, not dimension
   my $coll   = collate($ids, $people, $email, $create, $times);
 
 =head1 DESCRIPTION
@@ -429,7 +429,7 @@ calling each.
 Each function produces a list of elements that can be used as database columns.
 The handy C<collate()> function takes these columns and returns a list of
 (arrayref) rows.  This can then be processed into CSV, JSON, etc.  It can also
-be directly inserted into your favorite database, with your favorite perl ORM.
+be directly inserted into your favorite database.
 
 =head1 FUNCTIONS
 
@@ -466,11 +466,11 @@ B<end> times, and desired number of data-points are all optional.  The defaults
 are:
 
   stamp: 1 (boolean)
-  start: 00-00-00
+  start: 00:00:00
   end:   now (computed if not given)
   N:     10
 
-The times must be given as C<HH-MM-SS> strings.  The B<stamp> argument
+The times must be given as C<HH:MM:SS> strings.  The B<stamp> argument
 determines if a time-stamp or the number of seconds should be returned.
 
 =head2 number_ranger()
